@@ -1,34 +1,20 @@
-/*
- * -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- 
- */
+/* -*- mode: C; indent-tabs-mode: t; tab-width: 8; c-basic-offset: 2; -*- */
 
 /*
  * This file is part of Seed, the GObject Introspection<->Javascript bindings.
  *
- * Seed is free software: you can redistribute it and/or modify 
+ * Seed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version. 
- * Seed is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
- * GNU Lesser General Public License for more details. 
- * You should have received a copy of the GNU Lesser General Public License 
- * along with Seed.  If not, see <http://www.gnu.org/licenses/>. 
- * 
- * Copyright (C) Robert Carr 2008 <carrr@rpi.edu>
- */
-
-/**
- * SECTION:seed-value
- * @short_description: Conversion between, and manipulation of, Seed and C types.
- *
- */
-
-/**
- * SECTION:seed-string
- * @short_description: Manipulation of #SeedString objects.
+ * the License, or (at your option) any later version.
+ * Seed is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with Seed.  If not, see <http://www.gnu.org/licenses/>.
  *
+ * Copyright (C) Robert Carr 2009 <carrr@rpi.edu>
  */
 
 #ifndef _SEED_TYPES_H
@@ -53,7 +39,7 @@ gboolean seed_gvalue_from_seed_value (JSContextRef ctx,
 gboolean seed_gi_make_argument (JSContextRef ctx,
 				JSValueRef value,
 				GITypeInfo * type_info,
-				GIArgInfo *arg_info,
+				GIArgInfo * arg_info,
 				GArgument * arg, JSValueRef * exception);
 JSValueRef seed_gi_argument_make_js (JSContextRef ctx,
 				     GArgument * arg,
@@ -137,12 +123,10 @@ JSValueRef seed_value_from_string (JSContextRef ctx,
 				   const gchar * val, JSValueRef * exception);
 
 time_t seed_value_to_time_t (JSContextRef ctx,
-			     JSValueRef val,
-			     JSValueRef *exception);
+			     JSValueRef val, JSValueRef * exception);
 
 JSValueRef seed_value_from_time_t (JSContextRef ctx,
-				   time_t time,
-				   JSValueRef *exception);
+				   time_t time, JSValueRef * exception);
 
 GObject *seed_value_to_object (JSContextRef ctx,
 			       JSValueRef val, JSValueRef * exception);
@@ -151,13 +135,12 @@ JSValueRef seed_value_from_object (JSContextRef ctx,
 
 void seed_toggle_ref (gpointer data, GObject * object, gboolean is_last_ref);
 
-gboolean seed_validate_enum (GIEnumInfo *info, long val);
+gboolean seed_validate_enum (GIEnumInfo * info, long val);
 
 JSValueRef
 seed_value_from_binary_string (JSContextRef ctx,
-			       const gchar *bytes,
-			       gint n_bytes,
-			       JSValueRef *exception);
+			       const gchar * bytes,
+			       gint n_bytes, JSValueRef * exception);
 
 JSObjectRef seed_make_wrapper_for_type (JSContextRef ctx, GType type);
 
